@@ -21,6 +21,14 @@
 import yamlish
 import logging
 
+
+class NullHandler(logging.Handler):
+    def emit(self, record):
+        pass
+
+log = logging.getLogger("bayeux")
+log.addHandler(NullHandler())
+
 PASS = 0
 SKIP = 1
 TBD = 2  #IGNORE:W0511
@@ -52,11 +60,11 @@ class TAPGenerator(object):
         if reason:
             out_str += "\t# %s" % reason
         if data:
-            logging.debug("data:\n%s", data)
+            log.debug("data:\n%s", data)
             yamlish_str = yamlish.dumps(data)
-            logging.debug("yamlish_str:\n%s", yamlish_str)
+            log.debug("yamlish_str:\n%s", yamlish_str)
             line_str = self._indent(yamlish_str, "  ")
-            logging.debug("line_str:\n%s", line_str)
+            log.debug("line_str:\n%s", line_str)
             out_str += "\n%s" % line_str.rstrip()
         return out_str
 
